Index
$#! · 0-9 · A · B · C · D · E · F · G · H · I · J · K · L · M · N · O · P · Q · R · S · T · U · V · W · X · Y · Z

N |
| name, $.jqplot.CanvasOverlay
| needlePad, $.jqplot.MeterGaugeRenderer
| needleThickness, $.jqplot.MeterGaugeRenderer
| negativeColor, Series
| negativeSeriesColors, jqPlot
| neighborThreshold, Series
| newTheme, $.jqplot.ThemeEngine
| noDataIndicator, jqPlot
| numberColumns Global$.jqplot.DonutLegendRenderer$.jqplot.FunnelLegendRenderer$.jqplot.MekkoLegendRenderer$.jqplot.PieLegendRenderer
| numberRows Global$.jqplot.DonutLegendRenderer$.jqplot.FunnelLegendRenderer$.jqplot.MekkoLegendRenderer$.jqplot.PieLegendRenderer
| numberTicks, Axis
O |
| objects, $.jqplot.CanvasOverlay
| offset, $.jqplot.shadowRenderer
| offsetBars
| openColor, $.jqplot.OHLCRenderer
| Options Tutorial
| Options Usage
P |
| pad, Axis
| padding $.jqplot.DonutRenderer$.jqplot.FunnelRenderer$.jqplot.MeterGaugeRenderer$.jqplot.PieRenderer
| padMax, Axis
| padMin, Axis
| pegNeedle, $.jqplot.MeterGaugeRenderer
| placement, Legend
| position
| postDrawHooks, $.jqplot.$.jqplot
| postDrawSeriesHooks, $.jqplot.$.jqplot
| postDrawSeriesShadowHooks, $.jqplot.$.jqplot
| postInitHooks, $.jqplot.$.jqplot
| postParseOptionsHooks, $.jqplot.$.jqplot
| postParseSeriesOptionsHooks, $.jqplot.$.jqplot
| postSeriesInitHooks, $.jqplot.$.jqplot
| predraw, Legend
| preDrawHooks, $.jqplot.$.jqplot
| preDrawLegendHooks, $.jqplot.$.jqplot
| preDrawSeriesHooks, $.jqplot.$.jqplot
| preDrawSeriesShadowHooks, $.jqplot.$.jqplot
| prefix $.jqplot.AxisTickRenderer$.jqplot.CanvasAxisTickRenderer
| preInitHooks, $.jqplot.$.jqplot
| preParseOptionsHooks, $.jqplot.$.jqplot
| preParseSeriesOptionsHooks, $.jqplot.$.jqplot
| preSeriesInitHooks, $.jqplot.$.jqplot
| Properties Global plugins\jqplot.enhancedLegendRenderer.js plugins\jqplot.pyramidAxisRenderer.js plugins\jqplot.pyramidRenderer.js $.jqplot.AxisLabelRenderer$.jqplot.AxisTickRenderer$.jqplot.BarRenderer$.jqplot.BlockRenderer$.jqplot.BubbleRenderer$.jqplot.CanvasAxisLabelRenderer$.jqplot.CanvasAxisTickRenderer$.jqplot.CanvasOverlay$.jqplot.CategoryAxisRenderer$.jqplot.Cursor$.jqplot.DateAxisRenderer$.jqplot.DonutLegendRenderer$.jqplot.DonutRenderer$.jqplot.Dragable$.jqplot.FunnelLegendRenderer$.jqplot.FunnelRenderer$.jqplot.Highlighter$.jqplot.LinearAxisRenderer$.jqplot.LineRenderer$.jqplot.LogAxisRenderer$.jqplot.MarkerRenderer$.jqplot.MekkoAxisRenderer$.jqplot.MekkoLegendRenderer$.jqplot.MekkoRenderer$.jqplot.MeterGaugeRenderer$.jqplot.OHLCRenderer$.jqplot.PieLegendRenderer$.jqplot.PieRenderer$.jqplot.PointLabels$.jqplot.shadowRenderer$.jqplot.shapeRenderer$.jqplot.ThemeEngine$.jqplot.Trendline Axis DashedHorizontalLine DashedVerticalLine Grid HorizontalLine jqPlot Legend Line Series Title
| pt2px $.jqplot.CanvasAxisLabelRenderer$.jqplot.CanvasAxisTickRenderer
Q |
| quickInit, jqPlot
R |
| redraw, jqPlot
| reInitialize, jqPlot
| remove, $.jqplot.ThemeEngine
| rename, $.jqplot.ThemeEngine
| renderer $.jqplot.Trendline Axis Grid Series Title
| rendererOptions $.jqplot.Trendline Axis Grid Legend Series Title
| replot, jqPlot
| resetAxesScale, jqPlot
| restoreOriginalSeriesOrder, jqPlot
| restorePreviousSeriesOrder, jqPlot
| ringColor, $.jqplot.MeterGaugeRenderer
| ringMargin, $.jqplot.DonutRenderer
| ringWidth, $.jqplot.MeterGaugeRenderer
| rowSpacing, Legend

Optional name for the overlay object.

> this.needlePad = 6

Padding between needle and inner edge of the ring when the needle is at the min or max gauge value.

> this.needleThickness = null

Maximum thickness the needle.

> this.negativeColor

css color spec used for filled (area) plots that are filled to zero and the “useNegativeColors” option is true.

> this.negativeSeriesColors = $.jqplot.config.defaultNegativeColors

colors to use for portions of the line below zero.

> this.neighborThreshold = 4

how close or far (in pixels) the cursor must be from a point marker to detect the point.

> $.jqplot.ThemeEngine.prototype.newTheme = function( | name,
> | obj | )

Create a new theme based on the default theme, adding it the themeEngine.

> this.noDataIndicator = { show: false, indicator: 'Loading Data...', axes: { xaxis: { min: 0, max: 10, tickInterval: 2, show: true }, yaxis: { min: 0, max: 12, tickInterval: 3, show: true } } }

Options to set up a mock plot with a data loading indicator if no data is specified.

> this.numberColumns = null

Maximum number of columns in the legend.

> this.numberColumns = null

Maximum number of columns in the legend.

> this.numberColumns = null

Maximum number of columns in the legend.

> this.numberColumns = null

Maximum number of columns in the legend.

> this.numberColumns = null

Maximum number of columns in the legend.

> this.numberRows = null

Maximum number of rows in the legend.

> this.numberRows = null

Maximum number of rows in the legend.

> this.numberRows = null

Maximum number of rows in the legend.

> this.numberRows = null

Maximum number of rows in the legend.

> this.numberRows = null

Maximum number of rows in the legend.

> this.numberTicks

Desired number of ticks.

> this.objects = []

> this.offset = 1

Pixel offset at the given shadow angle of each shadow stroke from the last stroke.

> this.offsetBars = false

False will center bars on their y value.

> this.openColor = null

color of the open price tick mark.
This document will help you understand how jqPlot’s options relate to the API documentation and the jqPlot object itself.
See Options Tutorial

> this.pad = 1.2

Padding to extend the range above and below the data bounds.

> this.padding = 20

padding between the donut and plot edges, legend, etc.

> this.padding = {top: 20, right: 20, bottom: 20, left: 20}

padding between the funnel and plot edges, legend, etc.

> this.padding = null

padding between the meterGauge and plot edges, auto calculated by default.

> this.padding = 20

padding between the pie and plot edges, legend, etc.

> this.padMax = null

Padding to extend the range above data bounds.

> this.padMin = null

Padding to extend the range below data bounds.

> this.pegNeedle = true

True will stop needle just below/above the min/max values if data is below/above min/max, as if the meter is “pegged”.

> this.placement = "insideGrid"

“insideGrid” places legend inside the grid area of the plot.

> this.position = null

Position of axis.
called after plot draw.
called after each series is drawn.
called after series shadows are drawn.
called after initialization.
called after user options are parsed.
called after series related options are parsed.
called after series is initialized.
Wether to draw the legend before the series or not.
called before plot draw.
called before the legend is drawn.
called before each series is drawn.
called before series shadows are drawn.

> this.prefix = ''

String to prepend to the tick label.

> this.prefix = ''

String to prepend to the tick label.
called before initialization.
called before user options are parsed.
called before series related options are parsed.
called before series is initialized.
Properties
Axes options are specified within an axes object at the top level of the plot options like so:
These properties are specified at the top of the options object like so:
Properties will be assigned from a series array at the top level of the options.

> this.pt2px = null

Point to pixel scaling factor, used for computing height of bounding box around a label.

> this.pt2px = null

Point to pixel scaling factor, used for computing height of bounding box around a label.

> this.quickInit = function ()

Quick reinitialization plot for replotting.

> this.redraw = function( | clear | )

Empties the plot target div and redraws the plot.

> this.reInitialize = function ( | data,
> | opts | )

reinitialize plot for replotting.

> $.jqplot.ThemeEngine.prototype.remove = function( | name | )

Remove the given theme from the themeEngine.

> $.jqplot.ThemeEngine.prototype.rename = function ( | oldName,
> | newName | )

Rename a theme.

> this.renderer = new $.jqplot.LineRenderer()

Renderer to use to draw the trend line.

> this.renderer = $.jqplot.LinearAxisRenderer

A class of a rendering engine that handles tick generation, scaling input data to pixel grid units and drawing the axis element.

> this.renderer = $.jqplot.CanvasGridRenderer

Instance of a renderer which will actually render the grid, see $.jqplot.CanvasGridRenderer.

> this.renderer = $.jqplot.LineRenderer

A class of a renderer which will draw the series, see $.jqplot.LineRenderer.

> this.renderer = $.jqplot.DivTitleRenderer

A class for creating a DOM element for the title, see $.jqplot.DivTitleRenderer.

> this.rendererOptions = {marker:{show:false}}

Options to pass to the line renderer.

> this.rendererOptions = {}

renderer specific options.

> this.rendererOptions = {}

Options to pass on to the renderer, see $.jqplot.CanvasGridRenderer.

> this.rendererOptions = {}

renderer specific options passed to the renderer.

> this.rendererOptions = {}

Options to pass on to the renderer.

> this.rendererOptions = {}

renderer specific options passed to the renderer.

> this.replot = function( | options | )

Does a reinitialization of the plot followed by a redraw.

> this.resetAxesScale = function( | axes,
> | options | )

Reset the specified axes min, max, numberTicks and tickInterval properties to null or reset these properties on all axes if no list of axes is provided.

> this.restoreOriginalSeriesOrder = function ()

This method requires jQuery 1.4+ Restore the series canvas order to its original order when the plot was created.

> this.restorePreviousSeriesOrder = function ()

This method requires jQuery 1.4+ Restore the series canvas order to its previous state.

> this.ringColor = "#BBC6D0"

color of the outer ring, hub, and needle of the gauge.

> this.ringMargin = null

pixel distance between rings, or multiple series in a donut plot.

> this.ringWidth = null

width of the ring around the gauge.

> this.rowSpacing = '0.5em'

css padding-top spec for the rows in the legend.
Close